#[non_exhaustive]pub struct CreateTempIndex<'a> {
pub index: Option<&'a str>,
pub table: Option<&'a str>,
pub database: Option<&'a str>,
pub accessor: Option<&'a str>,
}Available on crate feature
__sqlite-shared only.Expand description
Authorizing a CREATE TEMP INDEX statement.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.index: Option<&'a str>Name of the index being created.
table: Option<&'a str>Name of the table the index is created on.
database: Option<&'a str>Database the object lives in ("main", "temp", or an ATTACH alias).
accessor: Option<&'a str>Inner-most trigger or view responsible for the access, if any.